function [aod_avg, count_sum, log_aod_avg] = JCGS_bv_func_read_MISR_AOD_level_3...
        (name_month_start, day_start, name_month_end, day_end)
%**************************************************************************
% FILE: JCGS_bv_func_read_MISR_AOD_level_3.m
%
% Contents: Load level-3 AOD daily data retrieved in a given period
% 
%**************************************************************************
%**************************************************************************
% INPUT parameters
%
%  name_month_start - the name of the starting month which should be 3
%  capital letters; for example, 'JUL' for July and 'AUG' for August
%  day_start - the date of the starting day 
%  name_month_end - the name of the ending month and of the the same format
%  as name_month_start
%  day_end - the date of the ending day 
%**************************************************************************
%**************************************************************************
% OUTPUT parameters
%
%  aod_avg - AOD 
%  count_sum - the number of level-2 data falling the pixel in the period
%  log_aod_avg - log(AOD) 
%**************************************************************************
name_year = '2001'; % it may be changes if data are not for this year

p=360; q=720;
data_sum =  zeros([p q]);
log_data_sum=zeros([p q]);
count_sum = zeros([p q]);

if(name_month_start(1)==name_month_end(1))
    name_month = name_month_start;
    for ind_day  = day_start:day_end
        if(ind_day<10)
            name_day = ['0' num2str(ind_day)];
        else
            name_day = num2str(ind_day);
        end
        name_hdf = ['MISR_AM1_CGAS_' name_month '_' name_day ...
            '_'  name_year '_F06_0017.hdf'];
        data = read_aod(name_hdf);
        count = read_aod_count(name_hdf);
        count = double(count);
        data_sum = data_sum + data.*(data>0).*count;
        log_data_sum=log_data_sum+log(data+0.00000000000001).*(data>0).*count;
        count_sum = count_sum + count.*(count>0);
    end 
else
    name_month = name_month_start;
    for ind_day  = day_start:31
        if(ind_day<10)
            name_day = ['0' num2str(ind_day)];
        else
            name_day = num2str(ind_day);
        end
        name_hdf = ['MISR_AM1_CGAS_' name_month '_' name_day ...
            '_'  name_year '_F06_0017.hdf'];
        data = read_aod(name_hdf);
        count = read_aod_count(name_hdf);
        count = double(count);
        data_sum = data_sum + data.*(data>0).*count;
        log_data_sum=log_data_sum+log(data+0.00000000000001).*(data>0).*count;
        count_sum = count_sum + count.*(count>0);
    end 
    name_month = name_month_end;
    for ind_day  = 1:day_end
        if(ind_day<10)
            name_day = ['0' num2str(ind_day)];
        else
            name_day = num2str(ind_day);
        end
        name_hdf = ['MISR_AM1_CGAS_' name_month '_' name_day ...
            '_'  name_year '_F06_0017.hdf'];
        data = read_aod(name_hdf);
        count = read_aod_count(name_hdf);
        count = double(count);
        data_sum = data_sum + data.*(data>0).*count;
        log_data_sum=log_data_sum+log(data+0.00000000000001).*(data>0).*count;
        count_sum = count_sum + count.*(count>0);
    end 
end    

aod_avg = data_sum./(count_sum+1e-16);   
aod_avg = aod_avg.*(count_sum>0);
log_aod_avg=log_data_sum./(count_sum+1e-16);
